"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PointyPostgres = void 0;
const PgConnString = require("pg-connection-string");
const typeorm_1 = require("typeorm");
const environment_1 = require("../environment");
const log_1 = require("../log");
const base_db_1 = require("./base-db");
/**
 * Postgres Database Handler
 */
class PointyPostgres extends base_db_1.BaseDb {
    connect(env) {
        return __awaiter(this, void 0, void 0, function* () {
            let pgOptions = {
                type: 'postgres',
            };
            if (!env) {
                env = environment_1.env;
            }
            log_1.log.debug('Using database driver: postgres');
            if (env.DATABASE_URL) {
                log_1.log.debug('Using connection from DATABASE_URL');
                const connstr = PgConnString.parse(env.DATABASE_URL);
                pgOptions = Object.assign(Object.assign({}, pgOptions), { host: connstr.host, port: parseInt(connstr.port, 10), database: connstr.database, ssl: !!connstr.ssl, username: connstr.user, password: connstr.password });
            }
            else {
                log_1.log.debug('Using connection from env');
                pgOptions = Object.assign(Object.assign({}, pgOptions), { host: env.POINTY_DB_HOST, port: env.POINTY_DB_PORT, database: env.POINTY_DB_NAME, ssl: !!env.POINTY_DB_SSL, username: env.POINTY_DB_USER, password: env.POINTY_DB_PASS });
                this.shouldSync = true;
            }
            const options = {
                name: this.connectionName,
                type: 'postgres',
                host: pgOptions.host,
                port: pgOptions.port,
                username: pgOptions.username,
                password: pgOptions.password,
                database: pgOptions.database,
                entities: this.entities,
                synchronize: this.shouldSync,
                ssl: pgOptions.ssl ?
                    { rejectUnauthorized: false } :
                    undefined,
                uuidExtension: pgOptions.uuidExtension
                    ? pgOptions.uuidExtension
                    : 'pgcrypto'
            };
            // Create connection
            const conn = yield (0, typeorm_1.createConnection)(options);
            if (conn && conn instanceof typeorm_1.Connection) {
                this.conn = conn;
                return this.conn;
            }
            else {
                throw new Error('Could not create connection');
            }
        });
    }
}
exports.PointyPostgres = PointyPostgres;
//# sourceMappingURL=postgres.js.map