"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteEndpoint = void 0;
const base_model_1 = require("../models/base-model");
const run_hook_1 = require("../utils/run-hook");
/**
 * Delete the object represent by the url key/value
 * @param request Request object to query by
 * @param response Response object to call responder with
 */
function deleteEndpoint(request, response) {
    return __awaiter(this, void 0, void 0, function* () {
        // Check response
        if (request.payload && request.payload instanceof base_model_1.BaseModel) {
            // Run model hook
            if (!(yield (0, run_hook_1.runHook)('delete', request.payload, request, response))) {
                return;
            }
            // Delete
            yield request.repository
                .remove(request.payload)
                .then((result) => __awaiter(this, void 0, void 0, function* () {
                if (!(yield (0, run_hook_1.runHook)('afterDelete', request.payload, request, response))) {
                    return;
                }
                response.deleteResponder(result);
            }))
                .catch((error) => response.error(error));
        }
        else {
            // No payload
            response.goneResponder(request.payload);
            return;
        }
    });
}
exports.deleteEndpoint = deleteEndpoint;
//# sourceMappingURL=delete-endpoint.js.map