"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loginEndpoint = void 0;
const bcryptjs_1 = require("bcryptjs");
const jwt_bearer_1 = require("../jwt-bearer");
const run_hook_1 = require("../utils/run-hook");
const read_filter_1 = require("../bodyguard/read-filter");
/**
 * Login endpoint
 * @param request Request object to query by
 * @param response Response object to call responder with
 */
function loginEndpoint(request, response) {
    return __awaiter(this, void 0, void 0, function* () {
        // Check input
        if (!('__user' in request.body)) {
            response.validationResponder('__user is required');
            return;
        }
        if (!('password' in request.body)) {
            response.validationResponder('password is required');
            return;
        }
        // Run model hook
        if (!(yield (0, run_hook_1.runHook)('login', request.body, request, response))) {
            return;
        }
        // Determine login __user fields
        const fields = ['username', 'email'];
        if (request.userType && 'tempEmail' in new request.userType()) {
            fields.push('tempEmail');
        }
        // Create where query
        const where = [];
        for (const field of fields) {
            const pair = {};
            pair[field] = request.body.__user;
            where.push(pair);
        }
        const foundUsers = yield request.repository
            .find({
            where: where
        })
            .catch((error) => response.error(error));
        // Check users
        if (!foundUsers || !foundUsers.length) {
            response.unauthorizedResponder('Could not authenticate user');
            return;
        }
        // Find match & check password
        let match;
        if (foundUsers && foundUsers instanceof Array) {
            foundUsers.forEach((foundUser) => {
                let isMatch = false;
                if ('password' in request.body &&
                    request.body.password &&
                    'password' in foundUser &&
                    foundUser['password']) {
                    isMatch = (0, bcryptjs_1.compareSync)(request.body.password, foundUser['password']);
                }
                if (isMatch) {
                    match = foundUser;
                }
            });
        }
        // Check matching user
        if (match) {
            // Create token
            const expiration = jwt_bearer_1.jwtBearer.getExpiration();
            const token = jwt_bearer_1.jwtBearer.sign(match);
            const refreshExpiration = jwt_bearer_1.jwtBearer.getExpiration(true);
            const refreshToken = jwt_bearer_1.jwtBearer.sign(match, true);
            if (token && refreshToken) {
                // Set request user
                request.user = match;
                // Create response
                match = (0, read_filter_1.readFilter)(match, request.user, request.payloadType, request.userType);
                match['expiration'] = expiration;
                match['token'] = token;
                match['refreshExpiration'] = refreshExpiration;
                match['refreshToken'] = refreshToken;
                // Send response
                if (!(yield (0, run_hook_1.runHook)('afterLogin', request.user, request, response))) {
                    return;
                }
                response.json(match);
            }
            else {
                // Couldn't create token
                response.error('Could not create create auth token');
            }
        }
        else {
            // No match found
            response.unauthorizedResponder('Could not authenticate user');
        }
    });
}
exports.loginEndpoint = loginEndpoint;
//# sourceMappingURL=login-endpoint.js.map