"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.patchEndpoint = void 0;
const class_validator_1 = require("class-validator");
const run_hook_1 = require("../utils/run-hook");
const models_1 = require("../models");
/**
 * Patch endpoint
 * @param request Request object to query by
 * @param response Response object to call responder with
 */
function patchEndpoint(request, response) {
    return __awaiter(this, void 0, void 0, function* () {
        // Run model hook
        if (!(yield (0, run_hook_1.runHook)('patch', request.body, request, response))) {
            return;
        }
        // Merge payload
        request.body = Object.assign(request.payload, request.body);
        // Pass null in place of empty strings
        for (const key in request.payload) {
            if (request.payload[key] === '') {
                request.payload[key] = null;
            }
        }
        // Validate
        const errors = yield (0, class_validator_1.validate)(request.body);
        // Check
        if (errors.length) {
            response.validationResponder(errors);
        }
        else {
            // Check if "timeUpdated" key exists in request payload
            if ('timeUpdated' in new request.payloadType()) {
                request.body.timeUpdated = (0, models_1.getISOTime)();
            }
            // Save
            yield request.repository
                .save(request.body)
                .then((result) => __awaiter(this, void 0, void 0, function* () {
                if (!(yield (0, run_hook_1.runHook)('afterPatch', request.payload, request, response))) {
                    return;
                }
                response.patchResponder(result);
            }))
                .catch((error) => response.error(error));
        }
    });
}
exports.patchEndpoint = patchEndpoint;
//# sourceMappingURL=patch-endpoint.js.map