"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.postEndpoint = void 0;
const class_validator_1 = require("class-validator");
const run_hook_1 = require("../utils/run-hook");
const read_filter_1 = require("../bodyguard/read-filter");
/**
 * Post endpoint
 * @param request Request object to query by
 * @param response Response object to call responder with
 */
function postEndpoint(request, response) {
    return __awaiter(this, void 0, void 0, function* () {
        // Run model hook
        if (!(yield (0, run_hook_1.runHook)('post', request.body, request, response))) {
            return;
        }
        if (request.body instanceof Array) {
            for (let i = 0; i < request.body.length; i++) {
                // Validate
                const errors = yield (0, class_validator_1.validate)(request.body[i]).catch((error) => response.error(error));
                // Check
                if (errors && errors.length) {
                    response.validationResponder(errors);
                    return;
                }
            }
            if (request.body.length) {
                // Get repo
                const repo = yield request.repository;
                // Get array of promises
                const promises = [];
                for (let i = 0; i < request.body.length; i++) {
                    promises.push(repo
                        .save(request.body[i])
                        .catch((error) => response.error(error)));
                }
                let results = yield Promise.all(promises);
                // Create result
                if (results) {
                    if (!(yield (0, run_hook_1.runHook)('afterPost', results, request, response))) {
                        return;
                    }
                    results = (0, read_filter_1.readFilter)(results, request.user, request.payloadType, request.userType);
                    // Send result
                    response.postResponder(results);
                }
            }
        }
        else {
            // Validate
            const errors = yield (0, class_validator_1.validate)(request.body).catch((error) => response.error(error));
            // Check
            if (errors && errors.length) {
                // Validation erros; respond with 400 Bad Request
                response.validationResponder(errors);
            }
            else {
                // Save
                yield request.repository
                    .save(request.body)
                    .then((result) => __awaiter(this, void 0, void 0, function* () {
                    if (!(yield (0, run_hook_1.runHook)('afterPost', result, request, response))) {
                        return;
                    }
                    // Create response
                    result = (0, read_filter_1.readFilter)(result, request.user, request.payloadType, request.userType);
                    // Send response and 200 Success
                    response.postResponder(result);
                }))
                    .catch((error) => response.error(error));
            }
        }
    });
}
exports.postEndpoint = postEndpoint;
//# sourceMappingURL=post-endpoint.js.map