"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.refreshTokenEndpoint = void 0;
const jwt_bearer_1 = require("../jwt-bearer");
const run_hook_1 = require("../utils/run-hook");
const read_filter_1 = require("../bodyguard/read-filter");
const models_1 = require("../models");
/**
 * Refresh the user's token
 * @param request Request object to query by
 * @param response Response object to call responder with
 */
function refreshTokenEndpoint(request, response) {
    return __awaiter(this, void 0, void 0, function* () {
        // Check request body
        if ('__refreshToken' in request.body) {
            // Check refresh token
            const token = jwt_bearer_1.jwtBearer.dryVerify(request.body.__refreshToken);
            if (token && 'isRefresh' in token && token.isRefresh) {
                // Load user
                let match = yield request.repository
                    .findOne({ id: token.id })
                    .catch((error) => response.error(error));
                // Check matching user
                if (match && match instanceof models_1.BaseUser) {
                    // Create token
                    const expiration = jwt_bearer_1.jwtBearer.getExpiration();
                    const token = jwt_bearer_1.jwtBearer.sign(match);
                    // Set request user
                    request.user = match;
                    // Create response
                    match = (0, read_filter_1.readFilter)(match, request.user, request.payloadType, request.userType);
                    match['expiration'] = expiration;
                    match['token'] = token;
                    // Send response
                    if (!(yield (0, run_hook_1.runHook)('tokenRefresh', request.user, request, response))) {
                        return;
                    }
                    response.json(match);
                }
                else {
                    // No match found
                    response.unauthorizedResponder('Could not authenticate user');
                }
            }
            else {
                // No match found
                response.unauthorizedResponder('Could not authenticate user');
            }
        }
        else {
            // Respond with 400
            response.validationResponder('No refresh token sent');
        }
    });
}
exports.refreshTokenEndpoint = refreshTokenEndpoint;
//# sourceMappingURL=refresh-token-endpoint.js.map