"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFilter = void 0;
const bodyguard_1 = require("../bodyguard");
const utils_1 = require("../utils");
const query_types_1 = require("../query-tools/query-types");
const enums_1 = require("../enums");
/**
 * Get Filter: Filter a GET response to remove private fields
 * @param request Request object to query by
 * @param response Response object to call responder with
 * @param next Next function to call on success
 */
function getFilter(request, response, next) {
    let denied = false;
    // Check incoming
    if (request.query) {
        const isAdminResult = (0, utils_1.isAdmin)(request.user);
        // Loop through object members
        let queryType;
        for (queryType of query_types_1.queryTypeKeys) {
            // Skip joins
            if (queryType === 'join' || queryType === 'additionalParameters') {
                continue;
            }
            const value = request.query[queryType];
            if (value instanceof Array) {
                for (let member of value) {
                    if (member.includes('.')) {
                        member = member.split('.')[0];
                    }
                    if (!(value[member] instanceof Function) &&
                        member.indexOf('__') !== 0) {
                        // Get read privileges for the field
                        const canRead = (0, bodyguard_1.getCanRead)(new request.payloadType(), member);
                        if (canRead === undefined ||
                            (canRead !== enums_1.BodyguardOwner.Anyone &&
                                ((canRead === enums_1.BodyguardOwner.Self &&
                                    !request.user) ||
                                    (canRead === enums_1.BodyguardOwner.Admin &&
                                        !isAdminResult)))) {
                            // User does not have privilege
                            denied = member;
                        }
                    }
                }
            }
            else if (value instanceof Object) {
                for (let member in value) {
                    if (member.includes('.')) {
                        member = member.split('.')[0];
                    }
                    if (!(value[member] instanceof Function) &&
                        member.indexOf('__') !== 0) {
                        // Get read privileges for the field
                        const canRead = (0, bodyguard_1.getCanRead)(new request.payloadType(), member);
                        if (canRead === undefined ||
                            (canRead !== enums_1.BodyguardOwner.Anyone &&
                                ((canRead === enums_1.BodyguardOwner.Self &&
                                    !request.user) ||
                                    (canRead === enums_1.BodyguardOwner.Admin &&
                                        !isAdminResult)))) {
                            // User does not have privilege
                            denied = member;
                        }
                    }
                }
            }
        }
    }
    if (denied) {
        // Cannot get by member, issue 403 Forbiddenn
        response.forbiddenResponder('Cannot get by member ' + denied);
    }
    else {
        // User is authorized, filter response payload
        request.payload = (0, bodyguard_1.readFilter)(request.payload, request.user, request.payloadType, request.userType);
        // Proceed
        next();
    }
}
exports.getFilter = getFilter;
//# sourceMappingURL=get-filter.js.map