"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.patchFilter = void 0;
const bodyguard_1 = require("../bodyguard");
const utils_1 = require("../utils");
/**
 * Patch Filter: Filter a PATCH request payload, and respond with
 * 	403 Forbidden if the request contains any private fields
 * @param request Request object to query by
 * @param response Response object to call responder with
 * @param next Next function to call on success
 */
function patchFilter(request, response, next) {
    // Check if user owns resource
    const isSelfResult = (0, utils_1.isSelf)(request.payload, request.user, request.payloadType, request.userType);
    // Check incoming payload for write privelege
    const writeFilterResult = (0, bodyguard_1.writeFilter)(request.body, request.user, request.payloadType, request.userType, isSelfResult);
    if (writeFilterResult === true) {
        // Patch body is okay, proceed
        next();
    }
    else {
        // Cannot write member, respond with 403 Forbidden
        response.forbiddenResponder('Cannot write member ' + writeFilterResult);
    }
}
exports.patchFilter = patchFilter;
//# sourceMappingURL=patch-filter.js.map