"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.onlyAdmin = void 0;
const base_user_1 = require("../models/base-user");
const is_admin_1 = require("../utils/is-admin");
/**
 * Only Admin Guard: Responds with 403 Forbidden if the
 * 	user is not an admin
 * @param request Request object to query by
 * @param response Response object to call responder with
 * @param next Next function to call on success
 */
function onlyAdmin(request, response, next) {
    if (request.user instanceof base_user_1.BaseUser) {
        if ((0, is_admin_1.isAdmin)(request.user)) {
            // User is admin
            next();
        }
        else {
            // User is not admin, respond with 403 Forbidden
            response.forbiddenResponder('not admin');
        }
    }
    else {
        // User is not authenticated, respond with 401 Unauthorized
        response.unauthorizedResponder('not admin');
    }
}
exports.onlyAdmin = onlyAdmin;
//# sourceMappingURL=only-admin.js.map