"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadEntity = void 0;
const get_identifier_value_1 = require("../utils/get-identifier-value");
/**
 * Load resource represented by the URL ID
 * Example:
 * 	/users/12 -> Load #12
 * @param request Express request
 * @param response Express response
 * @param next Next function to call on success
 * @return Returns a Promise of boolean
 */
function loadEntity(request, response, next) {
    return __awaiter(this, void 0, void 0, function* () {
        if (request.identifier) {
            const value = (0, get_identifier_value_1.getIdentifierValue)(request);
            if (value) {
                const result = yield request.repository
                    .findOne(value)
                    .catch(() => response.error('Could not load entity'));
                if (result && result instanceof request.payloadType) {
                    request.payload = result;
                    if (next) {
                        next();
                    }
                    return true;
                }
                else {
                    response.goneResponder('Could not load entity');
                    return false;
                }
            }
            else {
                response.validationResponder('Invalid request parameters');
            }
        }
        else {
            response.error('Could not load entity on a route without a parameter');
            return false;
        }
    });
}
exports.loadEntity = loadEntity;
//# sourceMappingURL=load-entity.js.map