"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadUser = void 0;
const typeorm_1 = require("typeorm");
const jwt_bearer_1 = require("../jwt-bearer");
const models_1 = require("../models");
/**
 * Load user if a JWT Bearer header exists
 * @param request Express request
 * @param response Express response
 * @param next Next function to call on success
 * @return Returns a Promise of boolean
 */
function loadUser(request, response, next) {
    return __awaiter(this, void 0, void 0, function* () {
        // Validate
        const tokenString = jwt_bearer_1.jwtBearer.getToken(request);
        if (tokenString) {
            const token = jwt_bearer_1.jwtBearer.dryVerify(tokenString);
            if (!token) {
                response.unauthorizedResponder('invalid token');
                return false;
            }
            // Verify
            const result = yield (0, typeorm_1.getRepository)(request.userType)
                .findOne({ id: token.id })
                .catch(() => response.error('Could not load user'));
            if (result && result instanceof models_1.BaseUser) {
                request.user = result;
                next();
                return true;
            }
            else {
                response.unauthorizedResponder('Could not load user');
                return false;
            }
        }
        else {
            next();
        }
    });
}
exports.loadUser = loadUser;
//# sourceMappingURL=load-user.js.map