"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getValidationConstraintsByKey = exports.getValidationConstraints = void 0;
const class_validator_1 = require("class-validator");
const container = (0, class_validator_1.getMetadataStorage)();
function getMetadata(someClass) {
    return container.getTargetValidationMetadatas(someClass, JSON.stringify(someClass), true, false);
}
function hasValidConstraints(constraints) {
    return constraints && Array.isArray(constraints) ?
        constraints.filter(c => c !== undefined).length > 0 :
        false;
}
function flatten(keyMetadata) {
    const output = {};
    for (const md of keyMetadata) {
        if (md.constraintCls) {
            const constraints = container.getTargetValidatorConstraints(md.constraintCls);
            for (const constraint of constraints) {
                output[constraint.name] = hasValidConstraints(md.constraints) ? md.constraints : true;
            }
        }
    }
    return output;
}
/**
 * Get class-validator constraints for a class
 * @param someClass BaseModel class(e.g `request.payloadType`)
 * @return Returns each constraint object for each property in the class
 */
function getValidationConstraints(someClass) {
    const metadata = getMetadata(someClass);
    const properties = container.groupByPropertyName(metadata);
    const output = {};
    for (const key in properties) {
        output[key] = flatten(properties[key]);
    }
    return output;
}
exports.getValidationConstraints = getValidationConstraints;
/**
 * Get class-validator constraints for a property of a class
 * @param someClass BaseModel class(e.g `request.payloadType`)
 * @param key Property key name
 * @return Returns each constraint object for the property
 */
function getValidationConstraintsByKey(someClass, key) {
    const metadata = getMetadata(someClass);
    return flatten(metadata.filter(md => md.propertyName === key));
}
exports.getValidationConstraintsByKey = getValidationConstraintsByKey;
//# sourceMappingURL=get-validation-constraints.js.map