"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMockRequest = void 0;
const mock_req_res_1 = require("mock-req-res");
const typeorm_1 = require("typeorm");
const models_1 = require("../models");
/**
 * Create mock request/response objects
 * @param method HTTP method verb for this request
 * @param url URL to mock the request
 * @return Returns { request, response }
 */
function createMockRequest(method = 'GET', url = '/api/v1/user') {
    // Create request
    const request = (0, mock_req_res_1.mockRequest)();
    request.repository = (0, typeorm_1.getRepository)(models_1.ExampleUser);
    request.method = method;
    request.baseUrl = url;
    request.userType = models_1.ExampleUser;
    request.payloadType = models_1.ExampleUser;
    request.joinMembers = [];
    request.identifier = 'id';
    request.header = (key) => (key === 'host' ? 'localhost' : false);
    // Create response
    const response = (0, mock_req_res_1.mockResponse)();
    // Conflict responder
    response.conflictResponder = (error) => fail('Conflict: ' + JSON.stringify(error));
    // Delete responder
    response.deleteResponder = (result) => fail('Delete: ' + JSON.stringify(result));
    // Forbidden responder
    response.forbiddenResponder = (error) => fail('Forbidden: ' + JSON.stringify(error));
    // Get responder
    response.getResponder = (result) => fail('Get: ' + JSON.stringify(result));
    // Error responder
    response.error = (error) => fail('Error: ' + JSON.stringify(error));
    // Gone responder
    response.goneResponder = (error) => fail('Gone: ' + JSON.stringify(error));
    // Post responder
    response.postResponder = (result) => fail('Post: ' + JSON.stringify(result));
    // Patch responder
    response.patchResponder = (result) => fail('Patch: ' + JSON.stringify(result));
    // Unauthorized responder
    response.unauthorizedResponder = (error) => fail('Unauthorized: ' + JSON.stringify(error));
    // Validation responder
    response.validationResponder = (error) => fail('Validation: ' + JSON.stringify(error));
    // Return request/response
    return { request, response };
}
exports.createMockRequest = createMockRequest;
//# sourceMappingURL=create-mock-request.js.map