"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.forkServer = void 0;
const fs = require("fs");
/**
 * # Fork Server
 *
 * Fork the server for testing
 *
 * ```typescript
 * import { pointy } from '../../../src/index';
 * import { forkServer } from '../../../src/fork-server';
 *
 * const http = pointy.http;
 *
 * let serverfork;
 *
 * beforeAll(async () => {
 * 	serverfork = await forkServer('./dist/test/examples/basic/server.js');
 * });
 *
 * afterAll(() => {
 * 	if (serverfork) {
 * 		serverfork.kill();
 * 	}
 * });
 *
 * describe('API Server', () => {
 * 	it('is running', async () => {
 * 		await http
 * 			.get('/', {}, undefined, [ 200, 404 ]);
 * 	});
 * });
 * ```
 *
 */
/**
 * Fork Server
 */
const child_process_1 = require("child_process");
/**
 * Fork the server from a test-suite
 * @param serverFile File path to the server entry-point
 * @return Returns a Promise
 */
function forkServer(serverFile, args = ['testmode']) {
    return __awaiter(this, void 0, void 0, function* () {
        return new Promise((accept, reject) => {
            fs.access(serverFile, (error) => {
                if (error) {
                    reject('Could not read server file: ' + JSON.stringify(error));
                }
                else {
                    const serverfork = (0, child_process_1.fork)(serverFile, args);
                    serverfork.on('message', (message) => {
                        accept(serverfork);
                    });
                }
            });
        });
    });
}
exports.forkServer = forkServer;
//# sourceMappingURL=fork-server.js.map