"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isSelf = void 0;
const enums_1 = require("../enums");
const get_bodyguard_keys_1 = require("../bodyguard/get-bodyguard-keys");
const compare_nested_1 = require("../bodyguard/compare-nested");
/**
 * Check if the user matches a BodyguardKey for the object
 * @param obj Object to check
 * @param user User to check for matching BodyguardKey
 * @param objType Type of object
 * @param userType Type of user
 * @param objBodyguardKeys Bodyguard keys which belong to the object
 * @param userBodyguardKeys Bodyguard keys which belong to the user
 * @return Returns if the user owns this object
 */
function isSelf(obj, user, objType, userType, objBodyguardKeys, userBodyguardKeys) {
    if (obj instanceof Array) {
        // Recurse array of objects
        for (let i = 0; i < obj.length; i++) {
            if (!isSelf(obj[i], user, objType, userType, objBodyguardKeys, userBodyguardKeys)) {
                return false;
            }
        }
        return true;
    }
    else {
        // Get bodyguard keys for object and user
        if (objBodyguardKeys === undefined) {
            objBodyguardKeys = (0, get_bodyguard_keys_1.getBodyguardKeys)(new objType());
        }
        if (userBodyguardKeys === undefined) {
            userBodyguardKeys = (0, get_bodyguard_keys_1.getBodyguardKeys)(new userType());
        }
        // Check user
        if (user) {
            // Admins pass isSelf regardless of user
            if (user.role === enums_1.UserRole.Admin) {
                return true;
            }
            // Check if obj is of user type
            if (objType === userType) {
                // Object is of type user
                for (const key of userBodyguardKeys) {
                    if (obj[key] !== undefined &&
                        `${obj[key]}` === `${user[key]}`) {
                        return true;
                    }
                }
            }
            else {
                // Object is not of type user
                // Check nested bodyguard keys
                return (0, compare_nested_1.compareNestedBodyguards)(obj, user, objBodyguardKeys, userBodyguardKeys);
            }
        }
        return false;
    }
}
exports.isSelf = isSelf;
//# sourceMappingURL=is-self.js.map