"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runHook = void 0;
const log_1 = require("../log");
/**
 * Run specified hook in the model
 * @param name Name of hook to run
 * @param obj Object to run hook on
 * @param request Request object to pass to hook
 * @param response Response object to pass to hook
 * @return Returns of a Promise of boolean
 */
function runHook(name, obj, request, response) {
    return __awaiter(this, void 0, void 0, function* () {
        // Run model hook
        let hookResult = false;
        let resultset;
        const promises = [];
        if (obj instanceof Array) {
            for (const each of obj) {
                if (name in each) {
                    promises.push(each[name].bind(each)(request, response));
                }
            }
        }
        else if (name in obj) {
            promises.push(obj[name].bind(obj)(request, response));
        }
        yield Promise.all(promises)
            .then((results) => {
            hookResult = true;
            resultset = results;
            for (let i = 0; i < results.length; i++) {
                if (!results[i]) {
                    hookResult = false;
                    break;
                }
            }
        })
            .catch((error) => {
            hookResult = false;
            log_1.log.error(error);
        });
        if (!hookResult) {
            // Hook failed
            if (!response.headersSent) {
                // Respond with 500 error if this has not responded yet
                response.error('Could not complete hook');
            }
            log_1.log.warn('Could not complete hook "' + name + '" on object: ', obj);
        }
        return hookResult ? resultset : false;
    });
}
exports.runHook = runHook;
//# sourceMappingURL=run-hook.js.map