"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.upgradeUserRole = void 0;
const typeorm_1 = require("typeorm");
const user_role_1 = require("../enums/user-role");
/**
 * Upgrade a user role for setting up dev users or creating test admins
 * @param username Username to upgrade
 * @param userConstructor User model to use
 * @param role User role to assign to the user
 * @return Return s a Promise
 */
function upgradeUserRole(username, userConstructor, role = user_role_1.UserRole.Admin) {
    return __awaiter(this, void 0, void 0, function* () {
        // Get user
        const user = yield (0, typeorm_1.getRepository)(userConstructor)
            .find({
            username: username
        })
            .catch((error) => {
            throw new Error('Could not upgrade user: ' + JSON.stringify(error));
        });
        // Check result
        if (user && user.length) {
            // Upgrade
            user[0]['role'] = role;
            // Save
            yield (0, typeorm_1.getRepository)(userConstructor)
                .save(user)
                .catch((error) => {
                throw new Error('Could not upgrade user: ' + JSON.stringify(error));
            });
            return user;
        }
        else {
            // Could not find user
            throw new Error(`Could not find user ${username} during upgrade`);
        }
    });
}
exports.upgradeUserRole = upgradeUserRole;
//# sourceMappingURL=upgrade-user-role.js.map