"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateAllowingStrings = exports.isIntString = void 0;
const class_validator_1 = require("class-validator");
/**
 * Check if a string is an integer (signed/unsigned)
 *
 * @param str String to check
 * @returns Returns true if the string is int
 */
function isIntString(str) {
    return (typeof str === 'string' &&
        Number.isInteger(Number(str)));
}
exports.isIntString = isIntString;
/**
 * Run validation on a model; allowing ints as strings
 *
 * @param obj Object to check
 * @returns Returns true if the string is int
 */
function validateAllowingStrings(obj) {
    const validationErrors = (0, class_validator_1.validateSync)(obj, {
        skipMissingProperties: true
    });
    return validationErrors.filter(error => {
        const constraints = error.constraints;
        if ('isInt' in constraints &&
            isIntString(error.value)) {
            delete constraints.isInt;
        }
        return Object.keys(error.constraints).length;
    });
}
exports.validateAllowingStrings = validateAllowingStrings;
//# sourceMappingURL=index.js.map